@@ -1,7 +1,6 @@
 use core_foundation_sys::base::OSStatus;
 use core_foundation_sys::string::CFStringRef;
-use libc::c_void;
-use MacTypes_sys::OSType;
+use std::os::raw::c_void;
 
 pub enum OpaqueSecKeychainRef {}
 pub type SecKeychainRef = *mut OpaqueSecKeychainRef;
@@ -9,7 +8,8 @@ pub type SecKeychainRef = *mut OpaqueSecKeychainRef;
 pub enum OpaqueSecKeychainItemRef {}
 pub type SecKeychainItemRef = *mut OpaqueSecKeychainItemRef;
 
-pub type SecKeychainAttrType = OSType;
+// OSType from MacTypes.h
+pub type SecKeychainAttrType = u32;
 
 #[repr(C)]
 #[derive(Copy, Clone)]
@@ -49,6 +49,7 @@ pub const errSecBadReq: OSStatus = -909;
 pub const errSecAuthFailed: OSStatus = -25293;
 pub const errSecTrustSettingDeny: OSStatus = -67654;
 pub const errSecNotTrusted: OSStatus = -67843;
+pub const errSecNoTrustSettings: OSStatus = -25263;
 
 extern "C" {
     #[cfg(target_os = "macos")]
